@@ -1,8 +1,8 @@
 # --- core imports
 import argparse
+from datetime import datetime
 import logging
 import os
-import re
 from pathlib import Path
 import sys
 
@@ -11,6 +11,7 @@ import pandas as pd
 from openpyxl import load_workbook, Workbook
 
 # --- application imports
+from geo_to_hca import version
 from geo_to_hca.utils import get_tab
 from geo_to_hca.utils import parse_reads
 from geo_to_hca.utils import sra_utils
@@ -20,27 +21,6 @@ DEFAULT_HCA_TEMPLATE = Path(__file__).resolve().parents[1] / "template/hca_templ
 log = logging.getLogger(__name__)
 
 
-def fetch_srp_accession(geo_accession: str) -> str:
-    """
-    Function to retrieve an SRA study accession given a GEO accession.
-    """
-    srp_accession = sra_utils.get_srp_accession_from_geo(geo_accession)
-    if not srp_accession:
-        raise IndexError(f"Could not find SRA accession; is it a GEO super-series? "
-                         f"If yes, please re-try with a sub-series accession")
-    if len(srp_accession) > 1:
-        raise IndexError("More than 1 accession has been found. Please re-try with a single SRA Study accession.")
-    return srp_accession[0]
-
-
-def fetch_srp_metadata(srp_accession: str) -> pd.DataFrame:
-    """
-    Function to get various metadata from the SRA database given an SRA study accession.
-    """
-    srp_metadata_df = sra_utils.get_srp_metadata(srp_accession)
-    return srp_metadata_df
-
-
 def fetch_fastq_names(srp_accession: str, srr_accessions: []) -> {}:
     """
     Function to try and get fastq file names from the SRA database or if not available, from the ENA
@@ -96,9 +76,20 @@ def integrate_metadata(srp_metadata: pd.DataFrame, fastq_map: {}, cols: []) -> p
 def save_spreadsheet_to_file(workbook: Workbook, accession: str, output_dir: str):
     log.info(f"Done. Saving workbook to excel file")
     out_file = f"{output_dir}/{accession}.xlsx"
+    set_workbook_properties(accession, workbook)
     workbook.save(out_file)
 
 
+def set_workbook_properties(accession, workbook):
+    workbook.properties.title = f'hca metadata for project from accession {accession}'
+    workbook.properties.version = version
+    workbook.properties.keywords = f'hca,metadata,{accession},{__package__}-{version}'
+    workbook.properties.creator = __package__
+    workbook.properties.lastModifiedBy = __package__
+    workbook.properties.created = datetime.now()
+    workbook.properties.modified = datetime.now()
+
+
 def create_spreadsheet_using_accession(accession, nthreads=1, hca_template=DEFAULT_HCA_TEMPLATE):
     try:
         workbook = load_workbook(filename=hca_template)
@@ -117,7 +108,7 @@ def create_spreadsheet_using_accession(accession, nthreads=1, hca_template=DEFAU
         if 'GSE' in accession:
             geo_accession = accession
             log.info(f"Fetching SRA study ID for GEO dataset {accession}")
-            srp_accession = fetch_srp_accession(accession)
+            srp_accession = sra_utils.get_srp_accession_from_geo(accession)
             log.info(f"Found SRA study ID: {srp_accession}")
         elif 'SRP' in accession or 'ERP' in accession:
             srp_accession = accession
@@ -129,7 +120,7 @@ def create_spreadsheet_using_accession(accession, nthreads=1, hca_template=DEFAU
         Fetch the SRA study metadata for the srp accession.
         """
         log.info(f"Fetching study metadata for SRA study ID: {srp_accession}")
-        srp_metadata = fetch_srp_metadata(srp_accession)
+        srp_metadata = sra_utils.get_srp_metadata(srp_accession)
 
         """
         Save the column names for later.
@@ -233,7 +224,7 @@ def create_spreadsheet_using_accession(accession, nthreads=1, hca_template=DEFAU
             log.info(f'Funders attribute error with accession {accession}')
         return workbook
     except Exception as e:
-        raise Exception(f'Error creating spreadsheet for accession {accession}. {e}')
+        raise Exception(f'Error creating spreadsheet for accession {accession}. {e}') from e
 
 
 def create_spreadsheet_using_accessions(accession_list, output_dir: str, nthreads=1,
@@ -262,6 +253,7 @@ def prepare_logging():
 
 def main():
     prepare_logging()
+    log.info(f'using {__package__}-{version}')
     """
     Parse user-provided command-line arguments.
     """
@@ -303,8 +295,8 @@ def main():
 
     try:
         create_spreadsheet_using_accessions(accession_list, args.output_dir, args.nthreads, args.template)
-    except Exception:
-        log.exception("")
+    except Exception as e:
+        log.exception(e)
 
 
 if __name__ == "__main__":
